"""
Configuration for Sphinx.
"""

extensions = [
    "sphinxcontrib.video",
    "sphinxnotes.strike",
    "sphinxcontrib_text_styles",
    "sphinx_notion",
    "sphinx_simplepdf",
    "sphinx_toolbox.collapse",
    "sphinx_toolbox.rest_example",
    "atsphinx.audioplayer",
    "sphinx_immaterial.task_lists",
    "sphinx.ext.mathjax",
]
